California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 001 - AUTHORIZES BONDS TO FUND SPECIFIED HOUSING ASSISTANCE PROGRAMS. LEGISLATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1401697 | AFFORDABLE HOUSING NOW - YES ON PROPS 1 & 2 COALITION: HOUSING CALIFORNIA, CALIFORNIA HOUSING CONSORTIUM, STATE BUILDING AND CONSTRUCTION TRADES COUNCIL OF CALIFORNIA AND SILICON VALLEY LEADERSHIP... | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406518 | CALIFORNIA HOMELESS AND HOUSING COALITION ACTION FUND, YES ON PROPS 1 & 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1411010 | A HOME FOR EVERYONE, YES ON PROPS 1 AND 2 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412754 | EAST BAY HOUSING ORGANIZATIONS (NON PROFIT 501C3) - YES ON PROPS 1, 2 & 10 & NO ON PROP 5 | SUPPORT